get_frames

Function get_frames 

pub fn get_frames<T: Serialize + Clone>(
    rules: &Vec<Rule<T>>,
    start: NaiveDateTime,
    end: NaiveDateTime,
) -> Vec<Frame<T>>
Rules priority is based on vector index, higher index means higher priority. One frame is a continuous time interval with a state. The state of a frame is determined by the highest priority rule that applies to it. Generic type T is the type of the payload.